#pragma once

#include "MultiIndex.h"

/**
 * \brief Minimal class representing a block of an equidistant D-dimensional
 * lattice.
 */
template<int D = 3, typename idx_ = int>
struct Block
{
    using idx = idx_;
    using CoordinatesType = MultiIndex<D, idx>;

    //! \brief Dimension of the lattice.
    static constexpr int dimension = D;

    //! \brief Offset of the block on the global lattice.
    CoordinatesType begin = 0;

    //! \brief Ending point of the block on the global lattice. The ending
    //! point is __not__ included in the block, i.e., the block spans the
    //! multidimensional interval `[begin, end)`.
    CoordinatesType end = 0;
};